module InformantCommon
  class Config
    def self.instance
      @instance ||= InformantCommon::Config.new
    end

    attr_writer :api_token
    def api_token
      @api_token ||= ENV['INFORMANT_API_KEY']
    end

    def enabled?
      !api_token.nil? && api_token != ''
    end

    attr_writer :exclude_models
    def exclude_models
      @exclude_models ||= []
    end

    attr_writer :filter_parameters
    def filter_parameters
      @filter_parameters ||= []
    end

    attr_writer :value_tracking
    def value_tracking?
      if !defined?(@value_tracking)
        @value_tracking = true
      else
        @value_tracking
      end
    end

    def self.collector_host
      @collector_host ||= ENV['INFORMANT_COLLECTOR_HOST'] || 'https://collector-api.informantapp.com'
    end

    def self.configure
      yield instance
    end

    def self.method_missing(name, *args)
      if instance.respond_to?(name)
        instance.public_send(name, *args)
      else
        super
      end
    end

    def self.respond_to_missing?(name)
      instance.respond_to?(name)
    end

    def self.reset!
      @instance = nil
    end
  end
end
